;; Generated package description from ack.el  -*- no-byte-compile: t -*-
(define-package "ack" "1.10.0.20200816.125814" "interface to ack-like tools" 'nil :keywords '("tools" "processes" "convenience") :authors '(("Leo Liu" . "sdl.web@gmail.com")) :maintainer '("João Távora" . "joaotavora@gmail.com") :url "https://github.com/leoliu/ack-el")
